==> kibana-7.4.0-1-any.pkg.tar.xz: usr/share/kibana/src/core/public/saved_objects/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "SavedObjectsBatchResponse", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBatchResponse;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBulkCreateObject;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBulkCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsClient", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsClient;
  }
});
Object.defineProperty(exports, "SavedObjectsClientContract", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsClientContract;
  }
});
Object.defineProperty(exports, "SavedObjectsCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindResponsePublic", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsFindResponsePublic;
  }
});
Object.defineProperty(exports, "SavedObjectsUpdateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsUpdateOptions;
  }
});
Object.defineProperty(exports, "SimpleSavedObject", {
  enumerable: true,
  get: function get() {
    return _simple_saved_object.SimpleSavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectsStart", {
  enumerable: true,
  get: function get() {
    return _saved_objects_service.SavedObjectsStart;
  }
});
Object.defineProperty(exports, "SavedObject", {
  enumerable: true,
  get: function get() {
    return _types.SavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectAttribute", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectAttribute;
  }
});
Object.defineProperty(exports, "SavedObjectAttributes", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectAttributes;
  }
});
Object.defineProperty(exports, "SavedObjectReference", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectReference;
  }
});
Object.defineProperty(exports, "SavedObjectsBaseOptions", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsBaseOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindOptions", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsFindOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsMigrationVersion", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsMigrationVersion;
  }
});

var _saved_objects_client = require("./saved_objects_client");

var _simple_saved_object = require("./simple_saved_object");

var _saved_objects_service = require("./saved_objects_service");

var _types = require("../../server/types");

==> kibana-7.5.0-1-any.pkg.tar.xz: usr/share/kibana/src/core/public/saved_objects/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "SavedObjectsBatchResponse", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBatchResponse;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBulkCreateObject;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsBulkCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsClient", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsClient;
  }
});
Object.defineProperty(exports, "SavedObjectsClientContract", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsClientContract;
  }
});
Object.defineProperty(exports, "SavedObjectsCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindResponsePublic", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsFindResponsePublic;
  }
});
Object.defineProperty(exports, "SavedObjectsUpdateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects_client.SavedObjectsUpdateOptions;
  }
});
Object.defineProperty(exports, "SimpleSavedObject", {
  enumerable: true,
  get: function get() {
    return _simple_saved_object.SimpleSavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectsStart", {
  enumerable: true,
  get: function get() {
    return _saved_objects_service.SavedObjectsStart;
  }
});
Object.defineProperty(exports, "SavedObject", {
  enumerable: true,
  get: function get() {
    return _types.SavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectAttribute", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectAttribute;
  }
});
Object.defineProperty(exports, "SavedObjectAttributes", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectAttributes;
  }
});
Object.defineProperty(exports, "SavedObjectAttributeSingle", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectAttributeSingle;
  }
});
Object.defineProperty(exports, "SavedObjectReference", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectReference;
  }
});
Object.defineProperty(exports, "SavedObjectsBaseOptions", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsBaseOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindOptions", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsFindOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsMigrationVersion", {
  enumerable: true,
  get: function get() {
    return _types.SavedObjectsMigrationVersion;
  }
});

var _saved_objects_client = require("./saved_objects_client");

var _simple_saved_object = require("./simple_saved_object");

var _saved_objects_service = require("./saved_objects_service");

var _types = require("../../server/types");
